BuildCandidate class

Represents an asset that is a candidate for building.

Contains information about the asset and its content needed by builders to determine if and how to process it.

Constructors

BuildCandidate(Asset asset, bool hasTopLevelMetadata, List<ExportedSymbol> exportedSymbols)
Creates a new build candidate with the specified asset and metadata.

Properties

asset → Asset
The asset that may be processed by a builder.
final
exportedSymbols → List<ExportedSymbol>
The symbols exported by this asset.
final
extension → String
The file extension of the asset (including the leading dot).
no setter
hasClasses → bool
Whether the asset contains any class definitions.
no setter
hasEnums → bool
Whether the asset contains any enum definitions.
no setter
hasExtensions → bool
Whether the asset contains any extension definitions.
no setter
hasFunctions → bool
Whether the asset contains any function definitions.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasMixins → bool
Whether the asset contains any mixin definitions.
no setter
hasTopLevelFunctions → bool
Whether the asset contains any top-level function definitions.
no setter
hasTopLevelMetadata → bool
Whether the file has top-level metadata annotations.
final
hasTopLevelVariables → bool
Whether the asset contains any top-level variable definitions.
no setter
isDartSource → bool
Whether this asset is a Dart source file.
no setter
path → String
The file path of the asset.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
The asset that may be processed by a builder. The URI of the asset.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited