ExportedSymbol class

Represents a symbol exported by an asset.

Contains the name and type of the symbol, which can be used by builders to identify classes, enums, or other Dart elements in a file.

Constructors

ExportedSymbol(String name, ReferenceType type)
Creates a new exported symbol with the specified name and type.

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
The name of the exported symbol.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ReferenceType
The type of the exported symbol (class, enum, etc.).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override