InvalidGenerationSourceError class

A description of a problem in the source input to code generation.

May be thrown by generators during Generator.generate to communicate a problem to the codegen user.

Implemented types

Constructors

InvalidGenerationSourceError(String message, {String todo = '', Element? element, AstNode? node})
Creates an InvalidGenerationSourceError with the given arguments.

Properties

element → Element?
The code element associated with this error.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
What failure occurred.
final
node → AstNode?
The AST Node associated with this error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
todo → String
What could have been changed in the source code to resolve this error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited