PackageFileResolverError class abstract

Base class for all resolver-related errors.

This exception is thrown when the resolver encounters issues with finding, parsing, or resolving Dart files and their dependencies.

Implemented types
Implementers

Constructors

PackageFileResolverError()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited