RuntimeTypeRegisterEntry class

Represents a runtime type entry used for registering type annotations.

This class stores information about a type that needs to be registered at runtime, including its name, optional import path, and source identifier.

Constructors

RuntimeTypeRegisterEntry(String name, String? import, String srcId)
Creates a new runtime type register entry.

Properties

hashCode → int
The hash code for this object.
no setteroverride
import → String?
Optional import path for the type, may be null if the type is from the same library.
final
name → String
The name of the type to be registered.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcId → String
Source identifier where this type is defined or referenced.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override