SharedPartBuilder class

A specialized Builder that generates Dart part files that can be shared by multiple generators.

This builder creates part files that must be included in the original library via a part directive. It can run multiple generators and combine their output into a single file.

Inheritance

Constructors

SharedPartBuilder(List<Generator> _generators, {String formatOutput(String code) = _defaultFormatOutput, bool allowSyntaxErrors = false, bool? writeDescriptions, BuilderOptions? options})
Creates a builder that generates shared part files.

Properties

allowSyntaxErrors → bool
Whether to continue processing even when syntax errors are present in input libraries.
finalinherited
formatOutput → String Function(String code)
Function that determines how the generated code is formatted.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
outputExtensions ↔ Set<String>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) → Future<void>
Generates the outputs for a given BuildStep.
inherited
generateForLibrary(LibraryElement library, BuildStep buildStep) → Future<void>
Generates code for the given library using all registered generators.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldBuildFor(BuildCandidate candidate) → bool
This is used to determine if the builder should be run for a given BuildCandidate.
inherited
toString() → String
A string representation of this object.
inherited
writeOutput(BuildStep buildStep, String content, String extension) → FutureOr<void>
Formats and writes the generated content to the output file.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

extension → const String
The extension used for shared part files.