ClassElementImpl class

Implementation for ClassElement.

Inheritance
Implemented types

Constructors

ClassElementImpl({required String name, required LibraryElementImpl library, required AstNode compilationUnit, required bool hasAbstract, required bool hasBase, required bool hasFinal, required bool hasInterface, required bool isMixinApplication, required bool isMixinClass, required bool hasSealedKeyword})
Creates an instance of ClassElementImpl.

Properties

accessors → List<PropertyAccessorElement>
The accessors of this element.
no setterinherited
allSupertypes → List<InterfaceType>
A list containing all of the supertypes of this interface.
no setterinherited
allTypeParameters → List<TypeParameterType>
Returns all type parameters of this element and its enclosing elements.
no setterinherited
codeLength → int
The length of the code of this element in the file that contains the
no setterinherited
codeOffset → int
The offset of the code of this element in the file that contains the
no setterinherited
compilationUnit → AstNode
The AST node representing the compilation unit of this element.
finalinherited
constructors → List<ConstructorElement>
The constructors of this element.
no setterinherited
didResolveMetadata ↔ bool
Whether the metadata of this element has been resolved.
getter/setter pairinherited
documentationComment ↔ String?
The documentation comment associated with this element if it has one.
getter/setter pairinherited
enclosingElement → Element?
The enclosing element of this element.
no setterinherited
fields → List<FieldElement>
The fields of this element.
no setterinherited
hasAbstract → bool
Whether the declaration has an explicit abstract modifier
final
hasAlwaysThrows → bool
Whether the element has an annotation of the form @alwaysThrows.
no setterinherited
hasBase → bool
Whether the declaration has an explicit base modifier.
final
hasDeprecated → bool
Whether the element has an annotation of the form @deprecated or @Deprecated('..').
no setterinherited
hasDoNotStore → bool
Whether the element has an annotation of the form @doNotStore.
no setterinherited
hasFactory → bool
Whether the element has an annotation of the form @factory.
no setterinherited
hasFinal → bool
Whether the declaration has an explicit final modifier
final
hashCode → int
The hash code for this object.
no setterinherited
hasInterface → bool
Whether the declaration has an explicit interface modifier
final
hasInternal → bool
Whether the element has an annotation of the form @internal.
no setterinherited
hasIsTest → bool
Whether the element has an annotation of the form @isTest.
no setterinherited
hasIsTestGroup → bool
Whether the element has an annotation of the form @isTestGroup.
no setterinherited
hasLiteral → bool
Whether the element has an annotation of the form @literal.
no setterinherited
hasMustBeOverridden → bool
Whether the element has an annotation of the form @mustBeOverridden.
no setterinherited
hasMustCallSuper → bool
Whether the element has an annotation of the form @mustCallSuper.
no setterinherited
hasNonVirtual → bool
Whether the element has an annotation of the form @nonVirtual.
no setterinherited
hasOptionalTypeArgs → bool
Whether the element has an annotation of the form @optionalTypeArgs.
no setterinherited
hasOverride → bool
Whether the element has an annotation of the form @override.
no setterinherited
hasProtected → bool
Whether the element has an annotation of the form @protected.
no setterinherited
hasRedeclare → bool
Whether the element has an annotation of the form @redeclare.
no setterinherited
hasReopen → bool
Whether the element has an annotation of the form @reopen.
no setterinherited
hasRequired → bool
Whether the element has an annotation of the form @required.
no setterinherited
hasSealed → bool
Whether the element has an annotation of the form @sealed.
no setterinherited
hasSealedKeyword → bool
Whether the declaration has an explicit sealed modifier.
final
hasUseResult → bool
Whether the element has an annotation of the form @useResult or @UseResult('..').
no setterinherited
hasVisibleForOverriding → bool
Whether the element has an annotation of the form @visibleForOverriding.
no setterinherited
identifier → String
A String that uniquely identifies this element
no setterinherited
interfaces → List<NamedDartType>
The interfaces of this element.
no setterinherited
isConstructable → bool
Whether the class can be instantiated.
no setteroverride
isMixinApplication → bool
Whether the class is a mixin application.
final
isMixinClass → bool
Whether the declaration has an explicit mixin modifier.
final
isPrivate → bool
Whether the name of this element starts with an underscore.
no setterinherited
isPublic → bool
Whether the name of this element does not start with an underscore.
no setterinherited
library → LibraryElementImpl
The library that contains this element.
finalinherited
librarySrc → Asset
The source code location of this element.
no setterinherited
metadata → List<ElementAnnotation>
The metadata associated with this element.
no setterinherited
metadataResolveCallback ↔ void Function()?
Callback to resolve metadata.
getter/setter pairinherited
methods → List<MethodElement>
The methods of this element.
no setterinherited
mixins → List<NamedDartType>
The mixins of this element.
no setterinherited
name → String
The name of the element.
finalinherited
nameLength → int
The length of the name of this element in the file that contains the declaration of this element, or 0 if this element does not have a name.
no setterinherited
nameOffset → int
The offset of the name of this element in the file that contains the declaration of this element, or -1 if this element is synthetic, does not have a name, or otherwise does not have an offset.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
The source code of this element.
no setterinherited
superType ↔ NamedDartType?
The supertype of this element, or null if this element does not have a supertype.
getter/setter pairinherited
thisType ↔ InterfaceType
The type of this in this element.
getter/setter pairinherited
typeParameters → List<TypeParameterType>
The type parameters of this element.
no setterinherited
unnamedConstructor → ConstructorElement?
The unnamed constructor of this element, or null if this element does not have an unnamed constructor.
no setterinherited

Methods

addConstructor(ConstructorElement constructor) → void
Adds a constructor to this element.
inherited
addField(FieldElement field) → void
Adds A field to this element.
inherited
addInterface(NamedDartType interface) → void
Adds an interface type to this element.
inherited
addMetadata(ElementAnnotation annotation) → void
Adds a metadata annotation to this element.
inherited
addMethod(MethodElement method) → void
Adds a Method to this element.
inherited
addMixin(NamedDartType mixin) → void
Adds a mixin type to this element.
inherited
addTypeParameter(TypeParameterType typeParameter) → void
Adds a type parameter to this element.
inherited
getAnnotation(String name) → ElementAnnotation?
Returns the first annotation with the given name, or null if no such
inherited
getConstructor(String name) → ConstructorElement?
Returns the constructor with the given name, or null if this element does not have a constructor with the given name.
inherited
getField(String name) → FieldElement?
Returns the field with the given name, or null if this element does not have a field with the given name.
inherited
getMethod(String name) → MethodElement?
Returns the method with the given name, or null if this element does not have a method with the given name.
inherited
hasConstructor(String name) → bool
Returns true if this element has a constructor with the given name.
inherited
hasField(String name) → bool
Returns true if this element has a field with the given name.
inherited
hasMethod(String name) → bool
Returns true if this element has a method with the given name.
inherited
hasPropertyAccessor(String name) → bool
Returns true if this element has a property accessor with the given name.
inherited
instantiate(NamedDartType typeRef) → DartType
instantiates the type parameters of this element with the given type
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCodeRange(AstNode? node, int offset, int length) → void
Sets the code range for this element.
inherited
setNameRange(int offset, int length) → void
Sets the name range for this element.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited