ConstFunctionReferenceImpl class

Implementation of a function reference constant.

Inheritance

Constructors

ConstFunctionReferenceImpl({required String name, required ExecutableElement element, required DeclarationRef declaration})
Creates a new function reference constant.

Properties

declaration → DeclarationRef
The declaration reference to the function.
final
element → ExecutableElement
The executable element representing the function.
final
hashCode → int
The hash code for this object.
no setteroverride
isBool → bool
Whether this constant represents a boolean value.
no setterinherited
isDouble → bool
Whether this constant represents a double value.
no setterinherited
isEnumValue → bool
Whether this constant represents an enum value.
no setterinherited
isFunctionReference → bool
Whether this constant represents a function reference.
no setterinherited
isInt → bool
Whether this constant represents an integer value.
no setterinherited
isInvalid → bool
Whether this constant represents an invalid constant.
no setterinherited
isList → bool
Whether this constant represents a list.
no setterinherited
isLiteral → bool
Whether this constant is a literal value.
no setterinherited
isMap → bool
Whether this constant represents a map.
no setterinherited
isNull → bool
Whether this constant represents null.
no setterinherited
isNum → bool
Whether this constant represents a numeric value.
no setterinherited
isObject → bool
Whether this constant represents an object.
no setterinherited
isSet → bool
Whether this constant represents a set.
no setterinherited
isString → bool
Whether this constant represents a string value.
no setterinherited
isSymbol → bool
Whether this constant represents a symbol.
no setterinherited
isType → bool
Whether this constant represents a type reference.
no setterinherited
literalValue → Object?
The literal Dart value represented by this constant.
no setteroverride
name → String
The name of the referenced function.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FunctionType
The function type of the referenced function.
no setteroverride
typeArguments → List<DartType>
Type arguments if the function is generic.
no setteroverride

Methods

addTypeArgument(DartType type) → void
Adds a type argument to this function reference.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override