InterfaceElementImpl class

Implementation for InterfaceElement.

Inheritance
Implemented types
Mixed-in types
Implementers

Constructors

InterfaceElementImpl({required String name, required LibraryElementImpl library, required AstNode compilationUnit})
Creates an instance of InterfaceElementImpl.

Properties

accessors → List<PropertyAccessorElement>
The accessors of this element.
no setteroverride
allSupertypes → List<InterfaceType>
A list containing all of the supertypes of this interface.
no setteroverride
allTypeParameters → List<TypeParameterType>
Returns all type parameters of this element and its enclosing elements.
no setterinherited
codeLength → int
The length of the code of this element in the file that contains the
no setterinherited
codeOffset → int
The offset of the code of this element in the file that contains the
no setterinherited
compilationUnit → AstNode
The AST node representing the compilation unit of this element.
final
constructors → List<ConstructorElement>
The constructors of this element.
no setteroverride
didResolveMetadata ↔ bool
Whether the metadata of this element has been resolved.
getter/setter pairinherited
documentationComment ↔ String?
The documentation comment associated with this element if it has one.
getter/setter pairinherited
enclosingElement → Element?
The enclosing element of this element.
no setteroverride
fields → List<FieldElement>
The fields of this element.
no setteroverride
hasAlwaysThrows → bool
Whether the element has an annotation of the form @alwaysThrows.
no setterinherited
hasDeprecated → bool
Whether the element has an annotation of the form @deprecated or @Deprecated('..').
no setterinherited
hasDoNotStore → bool
Whether the element has an annotation of the form @doNotStore.
no setterinherited
hasFactory → bool
Whether the element has an annotation of the form @factory.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasInternal → bool
Whether the element has an annotation of the form @internal.
no setterinherited
hasIsTest → bool
Whether the element has an annotation of the form @isTest.
no setterinherited
hasIsTestGroup → bool
Whether the element has an annotation of the form @isTestGroup.
no setterinherited
hasLiteral → bool
Whether the element has an annotation of the form @literal.
no setterinherited
hasMustBeOverridden → bool
Whether the element has an annotation of the form @mustBeOverridden.
no setterinherited
hasMustCallSuper → bool
Whether the element has an annotation of the form @mustCallSuper.
no setterinherited
hasNonVirtual → bool
Whether the element has an annotation of the form @nonVirtual.
no setterinherited
hasOptionalTypeArgs → bool
Whether the element has an annotation of the form @optionalTypeArgs.
no setterinherited
hasOverride → bool
Whether the element has an annotation of the form @override.
no setterinherited
hasProtected → bool
Whether the element has an annotation of the form @protected.
no setterinherited
hasRedeclare → bool
Whether the element has an annotation of the form @redeclare.
no setterinherited
hasReopen → bool
Whether the element has an annotation of the form @reopen.
no setterinherited
hasRequired → bool
Whether the element has an annotation of the form @required.
no setterinherited
hasSealed → bool
Whether the element has an annotation of the form @sealed.
no setterinherited
hasUseResult → bool
Whether the element has an annotation of the form @useResult or @UseResult('..').
no setterinherited
hasVisibleForOverriding → bool
Whether the element has an annotation of the form @visibleForOverriding.
no setterinherited
identifier → String
A String that uniquely identifies this element
no setterinherited
interfaces → List<NamedDartType>
The interfaces of this element.
no setteroverride
isPrivate → bool
Whether the name of this element starts with an underscore.
no setterinherited
isPublic → bool
Whether the name of this element does not start with an underscore.
no setterinherited
library → LibraryElementImpl
The library that contains this element.
final
librarySrc → Asset
The source code location of this element.
no setterinherited
metadata → List<ElementAnnotation>
The metadata associated with this element.
no setterinherited
metadataResolveCallback ↔ void Function()?
Callback to resolve metadata.
getter/setter pairinherited
methods → List<MethodElement>
The methods of this element.
no setteroverride
mixins → List<NamedDartType>
The mixins of this element.
no setteroverride
name → String
The name of the element.
final
nameLength → int
The length of the name of this element in the file that contains the declaration of this element, or 0 if this element does not have a name.
no setterinherited
nameOffset → int
The offset of the name of this element in the file that contains the declaration of this element, or -1 if this element is synthetic, does not have a name, or otherwise does not have an offset.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
The source code of this element.
no setterinherited
superType ↔ NamedDartType?
The supertype of this element, or null if this element does not have a supertype.
getter/setter pairoverride-getter
thisType ↔ InterfaceType
The type of this in this element.
getter/setter pairoverride-getter
typeParameters → List<TypeParameterType>
The type parameters of this element.
no setteroverride
unnamedConstructor → ConstructorElement?
The unnamed constructor of this element, or null if this element does not have an unnamed constructor.
no setteroverride

Methods

addConstructor(ConstructorElement constructor) → void
Adds a constructor to this element.
addField(FieldElement field) → void
Adds A field to this element.
addInterface(NamedDartType interface) → void
Adds an interface type to this element.
addMetadata(ElementAnnotation annotation) → void
Adds a metadata annotation to this element.
inherited
addMethod(MethodElement method) → void
Adds a Method to this element.
addMixin(NamedDartType mixin) → void
Adds a mixin type to this element.
addTypeParameter(TypeParameterType typeParameter) → void
Adds a type parameter to this element.
inherited
getAnnotation(String name) → ElementAnnotation?
Returns the first annotation with the given name, or null if no such
inherited
getConstructor(String name) → ConstructorElement?
Returns the constructor with the given name, or null if this element does not have a constructor with the given name.
override
getField(String name) → FieldElement?
Returns the field with the given name, or null if this element does not have a field with the given name.
override
getMethod(String name) → MethodElement?
Returns the method with the given name, or null if this element does not have a method with the given name.
override
hasConstructor(String name) → bool
Returns true if this element has a constructor with the given name.
override
hasField(String name) → bool
Returns true if this element has a field with the given name.
override
hasMethod(String name) → bool
Returns true if this element has a method with the given name.
override
hasPropertyAccessor(String name) → bool
Returns true if this element has a property accessor with the given name.
override
instantiate(NamedDartType typeRef) → DartType
instantiates the type parameters of this element with the given type
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCodeRange(AstNode? node, int offset, int length) → void
Sets the code range for this element.
inherited
setNameRange(int offset, int length) → void
Sets the name range for this element.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited