BuilderEntryImpl class

An implementation of BuilderEntry that wraps a standard builder.

This class handles the configuration and execution of a single builder, providing methods to determine which files to process and how to build them.

Implemented types

Constructors

BuilderEntryImpl(String key, BuilderFactory builder, {bool generateToCache = false, Set<String> generateFor = const <String>{}, Set<String> runsBefore = const <String>{}, Map<Type, String> registeredTypes = const <Type, String>{}, Set<String> applies = const <String>{}, Map<String, dynamic> options = const <String, dynamic>{}})
Creates a BuilderEntryImpl with a standard builder.
BuilderEntryImpl.forLibrary(String key, GeneratorFactory generator, {bool generateToCache = false, Set<String> generateFor = const <String>{}, Set<String> runsBefore = const <String>{}, Set<String> applies = const <String>{}, Map<String, dynamic> options = const <String, dynamic>{}, Map<Type, String> registeredTypes = const <Type, String>{}, bool allowSyntaxErrors = false, required Set<String> outputExtensions})
Creates a BuilderEntryImpl with a library builder.
factory
BuilderEntryImpl.forSharedPart(String key, GeneratorFactory generator, {bool generateToCache = false, Set<String> generateFor = const <String>{}, Set<String> runsBefore = const <String>{}, Map<String, dynamic> options = const <String, dynamic>{}, Map<Type, String> registeredTypes = const <Type, String>{}, bool allowSyntaxErrors = false, Set<String> applies = const <String>{}})
Creates a BuilderEntryImpl with a shared part builder.
factory

Properties

applies → Set<String>
A set of builder keys that this builder applies to.
final
builder → Builder
The wrapped builder that performs the actual code generation
final
generateFor → Set<String>
A set of glob patterns that determine which files this builder should process.
final
generateToCache → bool
Whether outputs should be generated to a cache directory.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
A unique identifier for this builder.
final
outputExtensions → Set<String>
The file extensions this builder will generate.
no setteroverride
registeredTypes → Map<Type, String>
A map from annotation types to their string representations
final
runsBefore → Set<String>
A set of builder keys that this builder should run before.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(ResolverImpl resolver, Asset asset) → FutureOr<Set<Uri>>
Builds the given asset using this builder.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPrepare(ResolverImpl resolver) → void
Prepares the resolver for this builder.
override
shouldGenerateFor(BuildCandidate candidate) → bool
Determines whether this builder should generate output for the given candidate.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited