DynamicType class

Represents the 'dynamic' type in Dart.

The dynamic type represents a value of any type, with runtime type checking.

Inheritance

Properties

element → Null
Non-element types don't have an associated element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isClass → bool
Whether this type refers to a ClassElement.
no setterinherited
isDartAsyncFuture → bool
Return true if this type represents the type '{TYPE}' defined in the dart:async library. Return true if this type represents the type '{TYPE}' defined in the dart:async library.
no setterinherited
isDartAsyncFutureOr → bool
Return true if this type represents the type '{TYPE}' defined in the dart:async library.
no setterinherited
isDartAsyncStream → bool
Return true if this type represents the type '{TYPE}' defined in the dart:async library.
no setterinherited
isDartCoreBigInt → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreBool → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library. Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreDateTime → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreDouble → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreEnum → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreFunction → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreInt → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreIterable → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreList → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreMap → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreNull → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreNum → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreObject → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreRecord → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreSet → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreString → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreSymbol → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDartCoreType → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setterinherited
isDynamic → bool
Return true if this type represents the type 'dynamic'
no setteroverride
isEnum → bool
Whether this type refers to an EnumElement.
no setterinherited
isInvalid → bool
Return true if this type represents the type 'Invalid'
no setterinherited
isMixin → bool
Whether this type refers to a MixinElement.
no setterinherited
isNever → bool
Return true if this type represents the type 'Never'
no setterinherited
isNullable → bool
Whether this type is nullable.
finalinherited
isValid → bool
Returns whether this type is valid (not an invalidType).
no setterinherited
isVoid → bool
Return true if this type represents the type 'void'
no setterinherited
name → String
The name of this non-element type.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withNullability(bool isNullable) → NonElementType
Returns a copy of this type with the specified nullability.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

instance → const DynamicType
The singleton instance of the dynamic type.