ReferenceType enum

An Enumeration representing the type of a reference in the asset graph.

Inheritance
Available extensions

Values

unknown → const ReferenceType

The reference type is unknown.

const ReferenceType(-1)
$class → const ReferenceType

Represents a class declaration.

const ReferenceType(0)
$mixin → const ReferenceType

Represents a mixin declaration.

const ReferenceType(1)
$extension → const ReferenceType

Represents an extension declaration.

const ReferenceType(2)
$enum → const ReferenceType

Represents an enum declaration.

const ReferenceType(3)
$typeAlias → const ReferenceType

Represents a type alias declaration.

const ReferenceType(4)
$function → const ReferenceType

Represents a function declaration.

const ReferenceType(5)
$variable → const ReferenceType

Represents a variable declaration.

const ReferenceType(6)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
representsANamedType → bool
Returns true if this reference type represents a named type.
no setter
representsInterfaceType → bool
Returns true if this reference type represents a class, mixin, or enum.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The value representing the reference type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(int value) → ReferenceType
Creates a ReferenceType from an integer value.

Constants

values → const List<ReferenceType>
A constant List of the values in this enum, in order of their declaration.