TypeImpl class abstract

Base implementation of the DartType interface.

Provides default implementations for many methods.

Inheritance
Implementers

Constructors

TypeImpl({required bool isNullable})
Creates a new TypeImpl with the specified nullability.
const

Properties

element → Element?
Return the element representing the declaration of this type, or null if the type is not associated with an element.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
isClass → bool
Whether this type refers to a ClassElement.
no setteroverride
isDartAsyncFuture → bool
Return true if this type represents the type '{TYPE}' defined in the dart:async library. Return true if this type represents the type '{TYPE}' defined in the dart:async library.
no setteroverride
isDartAsyncFutureOr → bool
Return true if this type represents the type '{TYPE}' defined in the dart:async library.
no setteroverride
isDartAsyncStream → bool
Return true if this type represents the type '{TYPE}' defined in the dart:async library.
no setteroverride
isDartCoreBigInt → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreBool → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library. Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreDateTime → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreDouble → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreEnum → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreFunction → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreInt → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreIterable → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreList → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreMap → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreNull → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreNum → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreObject → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreRecord → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreSet → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreString → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreSymbol → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDartCoreType → bool
Return true if this type represents the type '{TYPE}' defined in the dart:core library.
no setteroverride
isDynamic → bool
Return true if this type represents the type 'dynamic'
no setteroverride
isEnum → bool
Whether this type refers to an EnumElement.
no setteroverride
isInvalid → bool
Return true if this type represents the type 'Invalid'
no setteroverride
isMixin → bool
Whether this type refers to a MixinElement.
no setteroverride
isNever → bool
Return true if this type represents the type 'Never'
no setteroverride
isNullable → bool
Whether this type is nullable.
final
isValid → bool
Returns whether this type is valid (not an invalidType).
no setterinherited
isVoid → bool
Return true if this type represents the type 'void'
no setteroverride
name → String?
returns the name of the type if it's a named type otherwise returns null
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withNullability(bool isNullable) → DartType
Returns a copy of this type with the specified nullability.
override

Operators

operator ==(Object other) → bool
The equality operator.
override